@@ -9,5 +9,9 @@ def get_fake_valid_task():
     return load_json(path="beetmoverscript/test/test_work_dir/task.json")
 
 
-def get_fake_balrog_props(fake_context):
+def get_fake_balrog_props():
     return load_json(path="beetmoverscript/test/fake_balrog_props.json")
+
+
+def get_fake_balrog_manifest():
+    return load_json(path="beetmoverscript/test/fake_balrog_manifest.json")
