@@ -9,7 +9,8 @@ from beetmoverscript.script import setup_mimetypes, setup_config, put, retry_dow
 from beetmoverscript.test import get_fake_valid_config, get_fake_valid_task, get_fake_balrog_props
 from beetmoverscript.utils import generate_candidates_manifest
 from scriptworker.context import Context
-from scriptworker.exceptions import ScriptWorkerRetryException
+from scriptworker.exceptions import (ScriptWorkerRetryException,
+                                     ScriptWorkerTaskException)
 from scriptworker.test import event_loop, fake_session, fake_session_500
 
 assert event_loop  # silence flake8
@@ -98,7 +99,7 @@ def test_move_beets(event_loop):
     context = Context()
     context.config = get_fake_valid_config()
     context.task = get_fake_valid_task()
-    context.properties = get_fake_balrog_props(context)["properties"]
+    context.properties = get_fake_balrog_props()["properties"]
     context.properties['platform'] = context.properties['stage_platform']
     manifest = generate_candidates_manifest(context)
 
@@ -115,7 +116,7 @@ def test_move_beets(event_loop):
 
     actual_sources = []
     actual_destinations = []
-    async def fake_move_beet(context, source, locale, destinations):
+    async def fake_move_beet(context, source, destinations, locale, update_balrog_manifest):
         actual_sources.append(source)
         actual_destinations.append(destinations)
 
@@ -159,7 +160,7 @@ def test_move_beet(event_loop):
     with mock.patch('beetmoverscript.script.retry_download', fake_retry_download):
         with mock.patch('beetmoverscript.script.retry_upload', fake_retry_upload):
             event_loop.run_until_complete(
-                move_beet(context, target_source, locale, target_destinations)
+                move_beet(context, target_source, target_destinations, locale, update_balrog_manifest=False)
             )
 
     assert sorted(expected_download_args) == sorted(actual_download_args)
@@ -174,7 +175,7 @@ def test_async_main(event_loop):
         pass
 
     async def get_fake_props(context):
-        return get_fake_balrog_props(context)["properties"]
+        return get_fake_balrog_props()['properties']
 
     with mock.patch('beetmoverscript.script.move_beets', new=fake_move_beets):
         with mock.patch('beetmoverscript.script.get_props', new=get_fake_props):
@@ -190,5 +191,14 @@ def test_main(event_loop, fake_session):
     async def fake_async_main(context):
         pass
 
+    async def fake_async_main_with_exception(context):
+        raise ScriptWorkerTaskException("This is wrong, the answer is 42")
+
     with mock.patch('beetmoverscript.script.async_main', new=fake_async_main):
         main(name='__main__', config_path='beetmoverscript/test/fake_config.json')
+
+    with mock.patch('beetmoverscript.script.async_main', new=fake_async_main_with_exception):
+        try:
+            main(name='__main__', config_path='beetmoverscript/test/fake_config.json')
+        except SystemExit as exc:
+            assert exc.code == 1
